# serial-sphinx

[![License: AGPL v3](https://img.shields.io/badge/License-AGPL_v3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)
![Python Versions](https://img.shields.io/badge/python-3.7%20%7C%203.9%20%7C%203.10%20%7C%20-blue) 
![Style Black](https://warehouse-camo.ingress.cmh1.psfhosted.org/fbfdc7754183ecf079bc71ddeabaf88f6cbc5c00/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667) 
[![status-badge](https://ci.codeberg.org/api/badges/sail.black/serial-sphinx/status.svg)](https://ci.codeberg.org/sail.black/serial-sphinx)

# Why?

Rapid prototyping requires boilerplate code

# What?

`serial-sphinx` distills field knowledge about using sphinx for uploading your documentation to [readthedocs.org](www.readthedocs.org). 
Follow the [blog](https://medium.com/sail-black/get-your-docs-published-on-readthedocs-using-python-sphinx-in-less-than-7-minutes-using-5-87b10e651000) for more useful info. 

# Command snippets


```
rm -r docs 
cd docs
sphinx-quickstart
```
Copy the config file from the repository. Then, in the `docs` folder
```
sphinx-apidoc -o source/ ../<package_name>
make html
```
Make sure you follow the appropriate file structure outlined in the repository. 

Push it to you repo with the configured webhook, and you are done. 

# Proper testing
Please make sure to setup some CI/CD pipeline. If you are avoiding commercial setups, then this is a problem. 

For code quality, make sure you have great coverage by using `pytest-cov`. Check out the provided `setup.cfg` file. 

# Woodpecker CI 

Open-source CI. But not like Github-actions. Check the `.woodpecker.yml` for a tested standard workflow.

# Code-Coverage

The passing goal for the code-coverage should be edited in the `setup.cfg` under the key `addopts`